export P=python3-shapely
export V=1.6.4.post2
export B=4
export MAINTAINER=JuergenFischer

export PYTHON=Python37

savelog() {
	local f=$1
	rm -f $f.9
	for i in $(seq 8 -1 0); do [ -f "$f.$i" ] && mv $f.$i $f.$(( i + 1 )); done
	[ -f $f ] && mv $f $f.0
}

savelog package.log
exec > >(tee package.log) 2>&1
date

set -e

[ -f Shapely-$V.tar.gz ] || wget "https://files.pythonhosted.org/packages/a2/fb/7a7af9ef7a35d16fa23b127abee272cfc483ca89029b73e92e93cdf36e6b/Shapely-$V.tar.gz"
[ -f ../setup.py ] || tar -C .. --xform s,^Shapely-$V/,, -xzvf Shapely-1.6.4.post2.tar.gz

if ! [ -d "$OSGEO4W_REP" ]; then
        echo no repository
        exit 1
fi

fetchenv() {
        local IFS
        IFS=
        batch=$1
        shift

        if ! [ -f "$batch" ]; then
                echo "$batch not found"
                return 1
        fi

        srcenv=$(mktemp /tmp/srcenv.XXXXXXXXXX)
        dstenv=$(mktemp /tmp/dstenv.XXXXXXXXXX)
        diffenv=$(mktemp /tmp/diffenv.XXXXXXXXXX)
        envdiff=$(mktemp /tmp/envdiff.XXXXXXXXXX)
        cmd /c set >$srcenv
        cmd /c call $(cygpath -w $batch) "$@" \>nul 2\>nul \& set >$dstenv
        /usr/bin/cat <<EOF >$envdiff
/^+++/d;
/^[^+]/d;
s/^+//;
# s/\\\\/\\\\\\\\/g;
/^PATH=/ {
        s/\\\\/\\//g;
        s#\\([=;]\\)\\([a-zA-Z]\\):#\\1/cygdrive/\\2#g;
        s/;/:/g;
}
s/;/\\\\;/g;
s/^/export /;
s/=/='/;
s/\\\\r//g;
s/\r$/'/;
EOF
        /usr/bin/diff -u $srcenv $dstenv | /usr/bin/sed -f $envdiff >$diffenv
        . $diffenv
        PATH=$PATH:/bin:/usr/bin:/cygdrive/c/windows32/system32:/cygdrive/c/windows
        rm -f $srcenv $dstenv $diffenv $envdiff
}

for ARCH in x86_64 x86; do
	case "$ARCH" in
	x86)
		export OSGEO4W_ROOT=/c/OSGeo4W
		export VCARCH=x86
		;;

	x86_64)
		export OSGEO4W_ROOT=/c/OSGeo4W64
		export VCARCH=amd64
		;;

	*)
        	echo invalid arch
        	exit 1
		;;

	esac

	(
		export DISTUTILS_USE_SDK=1 MSSdk=1
		export R=$OSGEO4W_REP/$ARCH/release/python3/$P
		mkdir -p $R/$P

		cat <<EOF >$R/setup.hint
sdesc: "Geometric objects, predicates, and operations"
ldesc: "Geometric objects, predicates, and operations"
maintainer: $MAINTAINER
category: Libs
requires: python3-core geos
EOF
		
		cat <<EOF >/tmp/preremove.bat
call %OSGEO4W_ROOT%\\bin\\py3_env.bat
python -B %PYTHONHOME%\\Scripts\\preremove-cached.py $P
EOF

		fetchenv "$OSGEO4W_ROOT/bin/o4w_env.bat"
		fetchenv "$OSGEO4W_ROOT/bin/py3_env.bat"
		fetchenv "/c/Program Files (x86)/Microsoft Visual Studio 14.0/VC/vcvarsall.bat" $VCARCH

		export BUILDDIR=$(cygpath -am build-$ARCH)

		cd ..

		python3 setup.py \
			build \
			build_ext -L$(cygpath -aw $OSGEO4W_ROOT/lib) -lgeos_c -I$(cygpath -aw $OSGEO4W_ROOT/include) --build-temp $BUILDDIR \
			install --no-compile --install-base $(cygpath -aw $INSTDIR/apps/$PYTHON) --single-version-externally-managed --record osgeo4w/record-$ARCH.log

		cp LICENSE.txt $R/$P-$V-$B.txt

		pushd $OSGEO4W_ROOT
		/usr/bin/tar -cjf $R/$P-$V-$B.tar.bz2 \
			--xform s,tmp/preremove.bat,etc/preremove/$P.bat, \
			/tmp/preremove.bat \
			apps/$PYTHON/Lib/site-packages/shapely \
			apps/$PYTHON/Lib/site-packages/Shapely-$V-*.egg-info

		popd
		/usr/bin/tar -cjf $R/$P-$V-$B-src.tar.bz2 osgeo4w/package.sh
	)
done

date
